<p>
    {%- if last_updated %}
      {% trans prefix=translate('Last updated on'), last_updated=last_updated|e %}{{ prefix }} {{ last_updated }}.{% endtrans %}<br/>
    {%- endif %}
    {%- if theme_extra_footer %}
      <div class="extra_footer">
        {{ theme_extra_footer }}
      </div>
    {%- endif %}
  </p>
