{% extends "sphinx_book_theme/layout.html" %}

{% block extrahead %}
    <meta name="google-site-verification" content="vo35SZt_GASsTHAEmdww7AYKPCvZyzLvOXBl8guBME4" />
{% endblock %}

{% block docs_navbar %}
    {%- include "sections/header.html" %}
{% endblock %}

{%- block footer %}
    {%- include "sections/footer.html" %}
{%- endblock %}
