@font-face {
  font-display: swap;
  font-family: Open Sans;
  font-style: normal;
  font-weight: 300;
  src: local(""), url(./fonts/open-sans/open-sans-v34-latin-300.woff2) format("woff2"), url(./fonts/open-sans/open-sans-v34-latin-300.woff) format("woff");
  unicode-range: u+00??, u+0131, u+0152-0153, u+02bb-02bc, u+02c6, u+02da, u+02dc, u+2000-206f, u+2074, u+20ac, u+2122, u+2191, u+2193, u+2212, u+2215, u+feff, u+fffd; }
@font-face {
  font-display: swap;
  font-family: Open Sans;
  font-style: normal;
  font-weight: 400;
  src: local(""), url(./fonts/open-sans/open-sans-v34-latin-regular.woff2) format("woff2"), url(./fonts/open-sans/open-sans-v34-latin-regular.woff) format("woff");
  unicode-range: u+00??, u+0131, u+0152-0153, u+02bb-02bc, u+02c6, u+02da, u+02dc, u+2000-206f, u+2074, u+20ac, u+2122, u+2191, u+2193, u+2212, u+2215, u+feff, u+fffd; }
@font-face {
  font-display: swap;
  font-family: Open Sans;
  font-style: normal;
  font-weight: 500;
  src: local(""), url(./fonts/open-sans/open-sans-v34-latin-500.woff2) format("woff2"), url(./fonts/open-sans/open-sans-v34-latin-500.woff) format("woff");
  unicode-range: u+00??, u+0131, u+0152-0153, u+02bb-02bc, u+02c6, u+02da, u+02dc, u+2000-206f, u+2074, u+20ac, u+2122, u+2191, u+2193, u+2212, u+2215, u+feff, u+fffd; }
@font-face {
  font-display: swap;
  font-family: Open Sans;
  font-style: normal;
  font-weight: 600;
  src: local(""), url(./fonts/open-sans/open-sans-v34-latin-600.woff2) format("woff2"), url(./fonts/open-sans/open-sans-v34-latin-600.woff) format("woff");
  unicode-range: u+00??, u+0131, u+0152-0153, u+02bb-02bc, u+02c6, u+02da, u+02dc, u+2000-206f, u+2074, u+20ac, u+2122, u+2191, u+2193, u+2212, u+2215, u+feff, u+fffd; }
@font-face {
  font-display: swap;
  font-family: Open Sans;
  font-style: normal;
  font-weight: 700;
  src: local(""), url(./fonts/open-sans/open-sans-v34-latin-700.woff2) format("woff2"), url(./fonts/open-sans/open-sans-v34-latin-700.woff) format("woff");
  unicode-range: u+00??, u+0131, u+0152-0153, u+02bb-02bc, u+02c6, u+02da, u+02dc, u+2000-206f, u+2074, u+20ac, u+2122, u+2191, u+2193, u+2212, u+2215, u+feff, u+fffd; }
@font-face {
  font-display: swap;
  font-family: Open Sans;
  font-style: normal;
  font-weight: 800;
  src: local(""), url(./fonts/open-sans/open-sans-v34-latin-800.woff2) format("woff2"), url(./fonts/open-sans/open-sans-v34-latin-800.woff) format("woff");
  unicode-range: u+00??, u+0131, u+0152-0153, u+02bb-02bc, u+02c6, u+02da, u+02dc, u+2000-206f, u+2074, u+20ac, u+2122, u+2191, u+2193, u+2212, u+2215, u+feff, u+fffd; }
@font-face {
  font-display: swap;
  font-family: Open Sans;
  font-style: italic;
  font-weight: 300;
  src: local(""), url(./fonts/open-sans/open-sans-v34-latin-300italic.woff2) format("woff2"), url(./fonts/open-sans/open-sans-v34-latin-300italic.woff) format("woff");
  unicode-range: u+00??, u+0131, u+0152-0153, u+02bb-02bc, u+02c6, u+02da, u+02dc, u+2000-206f, u+2074, u+20ac, u+2122, u+2191, u+2193, u+2212, u+2215, u+feff, u+fffd; }
@font-face {
  font-display: swap;
  font-family: Open Sans;
  font-style: italic;
  font-weight: 400;
  src: local(""), url(./fonts/open-sans/open-sans-v34-latin-italic.woff2) format("woff2"), url(./fonts/open-sans/open-sans-v34-latin-italic.woff) format("woff");
  unicode-range: u+00??, u+0131, u+0152-0153, u+02bb-02bc, u+02c6, u+02da, u+02dc, u+2000-206f, u+2074, u+20ac, u+2122, u+2191, u+2193, u+2212, u+2215, u+feff, u+fffd; }
@font-face {
  font-display: swap;
  font-family: Open Sans;
  font-style: italic;
  font-weight: 500;
  src: local(""), url(./fonts/open-sans/open-sans-v34-latin-500italic.woff2) format("woff2"), url(./fonts/open-sans/open-sans-v34-latin-500italic.woff) format("woff");
  unicode-range: u+00??, u+0131, u+0152-0153, u+02bb-02bc, u+02c6, u+02da, u+02dc, u+2000-206f, u+2074, u+20ac, u+2122, u+2191, u+2193, u+2212, u+2215, u+feff, u+fffd; }
@font-face {
  font-display: swap;
  font-family: Open Sans;
  font-style: italic;
  font-weight: 600;
  src: local(""), url(./fonts/open-sans/open-sans-v34-latin-600italic.woff2) format("woff2"), url(./fonts/open-sans/open-sans-v34-latin-600italic.woff) format("woff");
  unicode-range: u+00??, u+0131, u+0152-0153, u+02bb-02bc, u+02c6, u+02da, u+02dc, u+2000-206f, u+2074, u+20ac, u+2122, u+2191, u+2193, u+2212, u+2215, u+feff, u+fffd; }
@font-face {
  font-display: swap;
  font-family: Open Sans;
  font-style: italic;
  font-weight: 700;
  src: local(""), url(./fonts/open-sans/open-sans-v34-latin-700italic.woff2) format("woff2"), url(./fonts/open-sans/open-sans-v34-latin-700italic.woff) format("woff");
  unicode-range: u+00??, u+0131, u+0152-0153, u+02bb-02bc, u+02c6, u+02da, u+02dc, u+2000-206f, u+2074, u+20ac, u+2122, u+2191, u+2193, u+2212, u+2215, u+feff, u+fffd; }
@font-face {
  font-display: swap;
  font-family: Open Sans;
  font-style: italic;
  font-weight: 800;
  src: local(""), url(./fonts/open-sans/open-sans-v34-latin-800italic.woff2) format("woff2"), url(./fonts/open-sans/open-sans-v34-latin-800italic.woff) format("woff");
  unicode-range: u+00??, u+0131, u+0152-0153, u+02bb-02bc, u+02c6, u+02da, u+02dc, u+2000-206f, u+2074, u+20ac, u+2122, u+2191, u+2193, u+2212, u+2215, u+feff, u+fffd; }
@font-face {
  font-display: swap;
  font-family: Open Sans;
  font-style: normal;
  font-weight: 300;
  src: local(""), url(./fonts/open-sans/open-sans-v34-latin-ext-300.woff2) format("woff2"), url(./fonts/open-sans/open-sans-v34-latin-ext-300.woff) format("woff");
  unicode-range: u+0100-024f, u+0259, u+1e??, u+2020, u+20a0-20ab, u+20ad-20cf, u+2113, u+2c60-2c7f, u+a720-a7ff; }
@font-face {
  font-display: swap;
  font-family: Open Sans;
  font-style: normal;
  font-weight: 400;
  src: local(""), url(./fonts/open-sans/open-sans-v34-latin-ext-regular.woff2) format("woff2"), url(./fonts/open-sans/open-sans-v34-latin-ext-regular.woff) format("woff");
  unicode-range: u+0100-024f, u+0259, u+1e??, u+2020, u+20a0-20ab, u+20ad-20cf, u+2113, u+2c60-2c7f, u+a720-a7ff; }
@font-face {
  font-display: swap;
  font-family: Open Sans;
  font-style: normal;
  font-weight: 500;
  src: local(""), url(./fonts/open-sans/open-sans-v34-latin-ext-500.woff2) format("woff2"), url(./fonts/open-sans/open-sans-v34-latin-ext-500.woff) format("woff");
  unicode-range: u+0100-024f, u+0259, u+1e??, u+2020, u+20a0-20ab, u+20ad-20cf, u+2113, u+2c60-2c7f, u+a720-a7ff; }
@font-face {
  font-display: swap;
  font-family: Open Sans;
  font-style: normal;
  font-weight: 600;
  src: local(""), url(./fonts/open-sans/open-sans-v34-latin-ext-600.woff2) format("woff2"), url(./fonts/open-sans/open-sans-v34-latin-ext-600.woff) format("woff");
  unicode-range: u+0100-024f, u+0259, u+1e??, u+2020, u+20a0-20ab, u+20ad-20cf, u+2113, u+2c60-2c7f, u+a720-a7ff; }
@font-face {
  font-display: swap;
  font-family: Open Sans;
  font-style: normal;
  font-weight: 700;
  src: local(""), url(./fonts/open-sans/open-sans-v34-latin-ext-700.woff2) format("woff2"), url(./fonts/open-sans/open-sans-v34-latin-ext-700.woff) format("woff");
  unicode-range: u+0100-024f, u+0259, u+1e??, u+2020, u+20a0-20ab, u+20ad-20cf, u+2113, u+2c60-2c7f, u+a720-a7ff; }
@font-face {
  font-display: swap;
  font-family: Open Sans;
  font-style: normal;
  font-weight: 800;
  src: local(""), url(./fonts/open-sans/open-sans-v34-latin-ext-800.woff2) format("woff2"), url(./fonts/open-sans/open-sans-v34-latin-ext-800.woff) format("woff");
  unicode-range: u+0100-024f, u+0259, u+1e??, u+2020, u+20a0-20ab, u+20ad-20cf, u+2113, u+2c60-2c7f, u+a720-a7ff; }
@font-face {
  font-display: swap;
  font-family: Open Sans;
  font-style: italic;
  font-weight: 300;
  src: local(""), url(./fonts/open-sans/open-sans-v34-latin-ext-300italic.woff2) format("woff2"), url(./fonts/open-sans/open-sans-v34-latin-ext-300italic.woff) format("woff");
  unicode-range: u+0100-024f, u+0259, u+1e??, u+2020, u+20a0-20ab, u+20ad-20cf, u+2113, u+2c60-2c7f, u+a720-a7ff; }
@font-face {
  font-display: swap;
  font-family: Open Sans;
  font-style: italic;
  font-weight: 400;
  src: local(""), url(./fonts/open-sans/open-sans-v34-latin-ext-italic.woff2) format("woff2"), url(./fonts/open-sans/open-sans-v34-latin-ext-italic.woff) format("woff");
  unicode-range: u+0100-024f, u+0259, u+1e??, u+2020, u+20a0-20ab, u+20ad-20cf, u+2113, u+2c60-2c7f, u+a720-a7ff; }
@font-face {
  font-display: swap;
  font-family: Open Sans;
  font-style: italic;
  font-weight: 500;
  src: local(""), url(./fonts/open-sans/open-sans-v34-latin-ext-500italic.woff2) format("woff2"), url(./fonts/open-sans/open-sans-v34-latin-ext-500italic.woff) format("woff");
  unicode-range: u+0100-024f, u+0259, u+1e??, u+2020, u+20a0-20ab, u+20ad-20cf, u+2113, u+2c60-2c7f, u+a720-a7ff; }
@font-face {
  font-display: swap;
  font-family: Open Sans;
  font-style: italic;
  font-weight: 600;
  src: local(""), url(./fonts/open-sans/open-sans-v34-latin-ext-600italic.woff2) format("woff2"), url(./fonts/open-sans/open-sans-v34-latin-ext-600italic.woff) format("woff");
  unicode-range: u+0100-024f, u+0259, u+1e??, u+2020, u+20a0-20ab, u+20ad-20cf, u+2113, u+2c60-2c7f, u+a720-a7ff; }
@font-face {
  font-display: swap;
  font-family: Open Sans;
  font-style: italic;
  font-weight: 700;
  src: local(""), url(./fonts/open-sans/open-sans-v34-latin-ext-700italic.woff2) format("woff2"), url(./fonts/open-sans/open-sans-v34-latin-ext-700italic.woff) format("woff");
  unicode-range: u+0100-024f, u+0259, u+1e??, u+2020, u+20a0-20ab, u+20ad-20cf, u+2113, u+2c60-2c7f, u+a720-a7ff; }
@font-face {
  font-display: swap;
  font-family: Open Sans;
  font-style: italic;
  font-weight: 800;
  src: local(""), url(./fonts/open-sans/open-sans-v34-latin-ext-800italic.woff2) format("woff2"), url(./fonts/open-sans/open-sans-v34-latin-ext-800italic.woff) format("woff");
  unicode-range: u+0100-024f, u+0259, u+1e??, u+2020, u+20a0-20ab, u+20ad-20cf, u+2113, u+2c60-2c7f, u+a720-a7ff; }

/*# sourceMappingURL=fonts.css.map */
