extensions = ["rocm_docs"]
html_theme = "rocm_docs_theme"
html_theme_options = {"flavor": "rocm-blogs"}

external_toc_path = "./sphinx/_toc.yml"

external_projects_current_project = "a"

version = "1.0.0"
release = "1.0.0"
html_title = f"ROCm Docs Core Theme Test Project - ROCm Blogs Flavor"
project = "ROCm Docs Core"
author = "Advanced Micro Devices, Inc."
copyright = (
    "Copyright (c) 2026 Advanced Micro Devices, Inc. All rights reserved."
)
