/**
 * \file
 * \author Jon Doe (jon@example.com)
 * \brief This file is here to showcase include hierarchies
 * \version 0.1
 * \date 2023-03-23
 *
 * \copyright Copyright (c) 2023 Advanced Micro Devices Inc.
 *
 */
