{% macro top_level_header(branch, latest_version, release_candidate_version) -%}
    {% if docs_header_version %}
        {% set version_name = docs_header_version %}
    {% elif branch in ["develop", "master", "main", "amd-master", "amd-staging"] %}
        {% set version_name = "Future Release" %}
    {% elif branch == "latest" %}
        {% set version_name = latest_version["rocm-ds"] %}
    {% else %}
        {% set version_name = branch %}
    {% endif %}
    <a class="klavika-font hover-opacity" href="{{ projects['rocm-ds'] }}">ROCm&#8482; Data Science {{ version_name }}</a>
{%- endmacro -%}

{% if theme_repository_url.endswith("-docs") %}
    {% set repo_url = theme_repository_url|replace("-docs", "") %}
{% else %}
    {% set repo_url = theme_repository_url %}
{% endif %}

{% set repo_url = repo_url|replace("http://", "https://") %}

{% macro version_list() -%}
    <a class="header-all-versions hover-opacity" href="https://rocm.docs.amd.com/projects/rocm-ds/en/latest/release/versions.html">Version List</a>
{%- endmacro -%}

{%
set nav_secondary_items = {
    "GitHub": repo_url,
    "Community": "https://github.com/ROCm/ROCm/discussions",
    "Blogs": "https://rocm.blogs.amd.com/",
    "ROCm Docs": "https://rocm.docs.amd.com",
    "ROCm Developer Hub": "https://www.amd.com/en/developer/resources/rocm-hub.html",
    "ROCm Toolkits": header_rocm_toolkits,
    "Systems and Infra Docs": "https://instinct.docs.amd.com",
    "Infinity Hub": "https://www.amd.com/en/developer/resources/infinity-hub.html",
    "Support": repo_url + "/issues/new/choose"
}
%}
